pub struct Bug { /* private fields */ }Expand description
VM encountered unexpected state. This is a bug. The execution must terminate since the VM is in an invalid state.
The bug it self is identified by the caller location.
Implementations
Sourceimpl Bug
impl Bug
Sourcepub fn new(variant: BugVariant) -> Self
pub fn new(variant: BugVariant) -> Self
Construct a new bug with the specified variant, using caller location for idenitfying the bug.
Sourcepub fn with_message<E: ToString>(self, error: E) -> Self
pub fn with_message<E: ToString>(self, error: E) -> Self
Set an additional error message.