AnyDebug

Trait AnyDebug 

pub trait AnyDebug: Any + Debug {
    // Required method
    fn as_any_ref(&self) -> &dyn Any;
}
A trait that combines the Debug and Any traits.

Required Methods

fn as_any_ref(&self) -> &dyn Any

Returns a reference to the underlying type as Any.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> AnyDebug for T
where T: Any + Debug,